Thin facade for the use-simulation workspace.
The crate reexports the focused simulation crates directly so consumers can opt into one dependency while still using the smaller APIs.
Examples
use use_simulation::*;
let seed = SimulationSeed::new(5);
let path = random_walk(RandomWalkConfig {
start: 0.0,
step_size: 1.0,
steps: 3,
seed,
})
.unwrap();
let result = summarize(&path).unwrap();
let mut clock = SimulationClock::new(0.5).unwrap();
assert_eq!(clock.advance().unwrap(), 0.5);
assert_eq!(result.steps, 3);
assert_eq!(step_state(1.0, 0.5, 0).unwrap().next_state, 1.5);Re-exports
pub use use_event_simulation;pub use use_monte_carlo;pub use use_random_walk;pub use use_seed;pub use use_simulation_clock;pub use use_simulation_result;pub use use_state_step;
Structs
- Event
State - Monte
Carlo Estimate - Random
Walk Config - Random
Walk Summary - Simulation
Clock - Simulation
Event - Simulation
Result - Simulation
Seed - State
Step
Enums
- Event
Simulation Error - Monte
Carlo Error - Random
Walk Error - Seed
Error - Simulation
Clock Error - Simulation
Result Error - State
Step Error